        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 16 <strong>control</strong><br>0,1,6,9,13,14,20,23,26,28,29,31,36,47,48,50';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 13 <br>3,12,16,19,21,25,27,33,37,42,44,45,46';}
       if(rr==3 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 10 <br>4,5,7,11,15,17,24,30,38,43';}
       if(rr==3 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>39</strong> miembros: 7 <br>2,10,22,34,39,40,41';}
       if(rr==3 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>49</strong> miembros: 5 <br>8,18,32,35,49';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 16 <strong>control</strong><br>0,1,6,9,13,14,20,23,26,28,29,31,36,47,48,50';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 13 <br>3,12,16,19,21,25,27,33,37,42,44,45,46';}
       if(rr==17 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 10 <br>4,5,7,11,15,17,24,30,38,43';}
       if(rr==17 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>39</strong> miembros: 7 <br>2,10,22,34,39,40,41';}
       if(rr==17 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>49</strong> miembros: 5 <br>8,18,32,35,49';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 16 <strong>control</strong><br>0,1,6,9,13,14,20,23,26,28,29,31,36,47,48,50';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 13 <br>3,12,16,19,21,25,27,33,37,42,44,45,46';}
       if(rr==19 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 10 <br>4,5,7,11,15,17,24,30,38,43';}
       if(rr==19 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>39</strong> miembros: 7 <br>2,10,22,34,39,40,41';}
       if(rr==19 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>49</strong> miembros: 5 <br>8,18,32,35,49';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 16 <strong>control</strong><br>0,1,6,9,13,14,20,23,26,28,29,31,36,47,48,50';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 13 <br>3,12,16,19,21,25,27,33,37,42,44,45,46';}
       if(rr==20 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 10 <br>4,5,7,11,15,17,24,30,38,43';}
       if(rr==20 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>39</strong> miembros: 7 <br>2,10,22,34,39,40,41';}
       if(rr==20 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>49</strong> miembros: 5 <br>8,18,32,35,49';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 16 <strong>control</strong><br>0,1,6,9,13,14,20,23,26,28,29,31,36,47,48,50';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 13 <br>3,12,16,19,21,25,27,33,37,42,44,45,46';}
       if(rr==21 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 10 <br>4,5,7,11,15,17,24,30,38,43';}
       if(rr==21 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>39</strong> miembros: 7 <br>2,10,22,34,39,40,41';}
       if(rr==21 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>49</strong> miembros: 5 <br>8,18,32,35,49';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 16 <strong>control</strong><br>0,1,6,9,13,14,20,23,26,28,29,31,36,47,48,50';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 13 <br>3,12,16,19,21,25,27,33,37,42,44,45,46';}
       if(rr==22 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 10 <br>4,5,7,11,15,17,24,30,38,43';}
       if(rr==22 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>4</strong> representante: <strong>39</strong> miembros: 7 <br>2,10,22,34,39,40,41';}
       if(rr==22 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260501 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>5</strong> representante: <strong>49</strong> miembros: 5 <br>8,18,32,35,49';}
}
